@@ -3,7 +3,7 @@ https://github.com/tiddlyweb/chrjs/raw/master/main.js
 ***/
 //{{{
 // TiddlyWeb adaptor
-// v0.14.2
+// v0.14.3
 
 /*jslint vars: true, unparam: true, nomen: true, white: true */
 /*global jQuery */
@@ -343,15 +343,19 @@ tw._capitalize = function(str) {
 
 // convert YYYYMMDDhhmmss timestamp to Date instance
 convertTimestamp = function(t) {
-	return new Date(Date.UTC(
-		parseInt(t.substr(0, 4), 10),
-		parseInt(t.substr(4, 2), 10) - 1,
-		parseInt(t.substr(6, 2), 10),
-		parseInt(t.substr(8, 2), 10),
-		parseInt(t.substr(10, 2), 10),
-		parseInt(t.substr(12, 2) || "0", 10),
-		parseInt(t.substr(14, 3) || "0", 10)
-	));
+	if (t.match(/^\d{12,17}$/)) {
+		return new Date(Date.UTC(
+			parseInt(t.substr(0, 4), 10),
+			parseInt(t.substr(4, 2), 10) - 1,
+			parseInt(t.substr(6, 2), 10),
+			parseInt(t.substr(8, 2), 10),
+			parseInt(t.substr(10, 2), 10),
+			parseInt(t.substr(12, 2) || "0", 10),
+			parseInt(t.substr(14, 3) || "0", 10)
+		));
+	} else {
+		return new Date(Date.parse(t));
+	}
 };
 
 // adapted from Crockford (http://javascript.crockford.com/remedial.html)
