@@ -6,13 +6,14 @@ listing, creation, subscription, etc.
 import urllib
 import simplejson
 
+from httpexceptor import HTTP403, HTTP404, HTTP409
+
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.recipe import Recipe
 from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.model.user import User
 from tiddlyweb.model.policy import Policy
 from tiddlyweb.store import NoRecipeError, NoBagError, NoUserError
-from tiddlyweb.web.http import HTTP403, HTTP404, HTTP409
 
 from tiddlywebplugins.utils import require_any_user
 
